@@ -256,7 +256,7 @@ class Module:
 
         def handler(c, u, message):
             if asyncio.iscoroutinefunction(cb):
-                asyncio.create_task(cb(message.topic, message.payload))
+                asyncio.run(cb(message.topic, message.payload))
             else:
                 cb(message.topic, message.payload)
 
